asr.database.material\_fingerprint
==================================

.. automodule:: asr.database.material_fingerprint

   
   
   .. rubric:: Functions

   
   .. autofunction:: todict
   
   

   
   
   

   
   
   